using UnityEngine;
using System;
using System.Collections.Generic;
using System.Collections;
using System.IO;
using UnityEngine.UI;
using System.Linq;
using TMPro;
using UnityEngine.Events;


//BASE SCRIPT
namespace Mod
{
    public class Mod
    {
        public static void Main()
        {

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Liquid Canister"), //item to get from
        NameOverride = "TearDown BlueTide Keg", //name
        DescriptionOverride = "A BlueTide Keg, this can be filled with liquids. any liquid.", //not needed
        CategoryOverride = ModAPI.FindCategory("Misc."), //category
        ThumbnailOverride = ModAPI.LoadSprite("bkthumb.png"), //thumnail image
        AfterSpawn = (Instance) => //after its spawned
        { 
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("bk.png"); //the texture for the item
            Instance.FixColliders(); //fix the colliders
        }  
    }
);


ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Brick"), //item to get from
        NameOverride = "TearDown Lee Computer", //name
        DescriptionOverride = "A collectable safe. press F on it to collect it.", //not needed
        CategoryOverride = ModAPI.FindCategory("Misc."), //category
        ThumbnailOverride = ModAPI.LoadSprite("leethumb.png"), //thumnail image
        AfterSpawn = (Instance) => //after its spawned
        { 
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("leec.png"); //the texture for the item
            Instance.FixColliders(); //fix the colliders
        }  
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Activation Fuse"), //item to get from
        NameOverride = "TearDown safe-01", //name
        DescriptionOverride = "A collectable safe. press F on it to collect it.", //not needed
        CategoryOverride = ModAPI.FindCategory("Misc."), //category
        ThumbnailOverride = ModAPI.LoadSprite("safe1thumb.png"), //thumnail image
        AfterSpawn = (Instance) => //after its spawned
        { 
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("safe1.png"); //the texture for the item
            Instance.FixColliders(); //fix the colliders
        }  
    }
);


ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Activation Fuse"), //item to get from
        NameOverride = "TearDown safe-00", //name
        DescriptionOverride = "A collectable safe. press F on it to collect it.", //not needed
        CategoryOverride = ModAPI.FindCategory("Misc."), //category
        ThumbnailOverride = ModAPI.LoadSprite("safethumb.png"), //thumnail image
        AfterSpawn = (Instance) => //after its spawned
        { 
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("safe.png"); //the texture for the item
            Instance.FixColliders(); //fix the colliders
        }  
    }
);


ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Hammer"), //item to get from
        NameOverride = "TearDown Sledge", //name
        DescriptionOverride = "The Sledge, otherwise known as the Hammer, is a tool in Teardown that allows the player to swing and break down weak objects at a close range.", //not needed
        CategoryOverride = ModAPI.FindCategory("Melee"), //category
        ThumbnailOverride = ModAPI.LoadSprite("hammerthumb.png"), //thumnail image
        AfterSpawn = (Instance) => //after its spawned
        { 
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("hammer.png"); //the texture for the item
            Instance.FixColliders(); //fix the colliders
        }  
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Revolver"), //item to derive from
        NameOverride = "TearDown Silenced Gun", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "A silent version of the Gun.", //new item description
        CategoryOverride = ModAPI.FindCategory("Firearms"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("sgunthumb.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //setting the sprite
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("sgun.png");

            //getting the FirearmBehaviour for later manipulation
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //creating a custom cartridge for the gun
            Cartridge customCartridge = ModAPI.FindCartridge("9mm"); //load a copy of the 9mm cartridge
            customCartridge.name = "9mm"; //set a name
            customCartridge.Damage *= 25f; //change the damage however you like
            customCartridge.StartSpeed *= 207368f; //change the bullet velocity
            customCartridge.PenetrationRandomAngleMultiplier *= 0.5f; //change the accuracy when the bullet travels through an object
            customCartridge.Recoil *= 0.6f; //change the recoil
            customCartridge.ImpactForce *= 0f; //change how much the bullet pushes the target

            //set the cartridge to the FirearmBehaviour
            firearm.Cartridge = customCartridge;

            //set the new gun sounds. this is an array of AudioClips that is picked from at random when shot
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("gun1.wav"),                               
            };

            // set the collision box to the new sprite shape
            // this is the easiest way to fix your collision shape, but it also the slowest.
            Instance.FixColliders();
        }
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Shotgun"), //item to derive from
        NameOverride = " TearDown Tac-Shotgun", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "The Shotgun is a destructive tool in Teardown, used for breaking down materials by blasting them at close range, often leaving several holes in walls and surfaces. It functions as a more destructive, chaotic, and close-range variant to the Gun.", //new item description
        CategoryOverride = ModAPI.FindCategory("Firearms"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("tshotgunthumb.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //setting the sprite
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("tshotgun.png");

            //getting the FirearmBehaviour for later manipulation
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //creating a custom cartridge for the gun
            Cartridge customCartridge = ModAPI.FindCartridge("50 AE"); //load a copy of the 9mm cartridge
            customCartridge.name = "Buckshot"; //set a name
            customCartridge.Damage *= 40f; //change the damage however you like
            customCartridge.StartSpeed *= 7368f; //change the bullet velocity
            customCartridge.PenetrationRandomAngleMultiplier *= 0.5f; //change the accuracy when the bullet travels through an object
            customCartridge.Recoil *= 0.4f; //change the recoil
            customCartridge.ImpactForce *= 1f; //change how much the bullet pushes the target

            //set the cartridge to the FirearmBehaviour
            firearm.Cartridge = customCartridge;

            //set the new gun sounds. this is an array of AudioClips that is picked from at random when shot
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("shot1.wav"),           
            };

            // set the collision box to the new sprite shape
            // this is the easiest way to fix your collision shape, but it also the slowest.
            Instance.FixColliders();
        }
    }
);


ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Plastic Barrel"), //item to get from
        NameOverride = "TearDown BlueTide Barrel", //name
        DescriptionOverride = "a barrel from BlueTide.", //not needed
        CategoryOverride = ModAPI.FindCategory("Misc."), //category
        ThumbnailOverride = ModAPI.LoadSprite("barrelthumb.png"), //thumnail image
        AfterSpawn = (Instance) => //after its spawned
        { 
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("barrel.png"); //the texture for the item
            Instance.FixColliders(); //fix the colliders
        }  
    }
);


ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Handgrenade"),
        NameOverride = "TearDown Bomb",
        DescriptionOverride = "The Bomb is a tool that can be placed and will automatically explode. Before Part 2 it was one of the most powerful tools in Teardown in terms of destructive power. Additionally one of the placeable tools in Teardown. After placement, a 2.5 second timer starts prior to the detonation. Upon detonation, it will leave a very large hole, more than enough to walk through.",
        CategoryOverride = ModAPI.FindCategory("Explosives"),
        ThumbnailOverride = ModAPI.LoadSprite("bombthumb.png"),
        AfterSpawn = (Instance) =>
        { 
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("bomb.png");
            Instance.FixColliders();
        }  
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Pink Explosive"),
        NameOverride = "TearDown Nitroglycerin",
        DescriptionOverride = "Nitroglycerin is the most powerful explosive tool in Teardown in terms of blast power.",
        CategoryOverride = ModAPI.FindCategory("Explosives"),
        ThumbnailOverride = ModAPI.LoadSprite("nitrothumb.png"),
        AfterSpawn = (Instance) =>
        { 
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("nitro.png");
            Instance.FixColliders();
        }  
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("General Purpose Bomb"),
        NameOverride = "TearDown Powerplant Bomb",
        DescriptionOverride = "was used for making power, but now its used for making craters.",
        CategoryOverride = ModAPI.FindCategory("Explosives"),
        ThumbnailOverride = ModAPI.LoadSprite("powerthumb.png"),
        AfterSpawn = (Instance) =>
        { 
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("power.png");
            Instance.FixColliders();
        }  
    }
);


ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Red Barrel"),
        NameOverride = "TearDown Propane Tank",
        DescriptionOverride = "a fragile tank of methane. very unstable.",
        CategoryOverride = ModAPI.FindCategory("Explosives"),
        ThumbnailOverride = ModAPI.LoadSprite("prothumb.png"),
        AfterSpawn = (Instance) =>
        { 
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("pro.png");
            Instance.FixColliders();
        }  
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Red Barrel"),
        NameOverride = "TearDown Blowtorch Tank",
        DescriptionOverride = "a fragile Blowtorch tank. kinda unstable.",
        CategoryOverride = ModAPI.FindCategory("Explosives"),
        ThumbnailOverride = ModAPI.LoadSprite("torchthumb.png"),
        AfterSpawn = (Instance) =>
        { 
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("torch.png");
            Instance.FixColliders();
        }  
    }
);


ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Handgrenade"),
        NameOverride = "TearDown PipeBomb",
        DescriptionOverride = "The Pipe Bomb is the only throwable tool in Teardown. The pipe bomb is slightly more powerful than the shotgun, but less powerful than the rocket launcher. Like all other explosives, it has a chance to set some materials on fire. However, it has extremely poor precision, and it can backfire easily.",
        CategoryOverride = ModAPI.FindCategory("Explosives"),
        ThumbnailOverride = ModAPI.LoadSprite("pipebombthumb.png"),
        AfterSpawn = (Instance) =>
        { 
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("pipebomb.png");
            Instance.FixColliders();
        }  
    }
);


ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Shotgun"), //item to derive from
        NameOverride = " TearDown Shotgun", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "The Shotgun is a destructive tool in Teardown, used for breaking down materials by blasting them at close range, often leaving several holes in walls and surfaces. It functions as a more destructive, chaotic, and close-range variant to the Gun.", //new item description
        CategoryOverride = ModAPI.FindCategory("Firearms"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("shotgunthumb.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //setting the sprite
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("shotgun.png");

            //getting the FirearmBehaviour for later manipulation
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //creating a custom cartridge for the gun
            Cartridge customCartridge = ModAPI.FindCartridge("9mm"); //load a copy of the 9mm cartridge
            customCartridge.name = "Buckshot"; //set a name
            customCartridge.Damage *= 35f; //change the damage however you like
            customCartridge.StartSpeed *= 7368f; //change the bullet velocity
            customCartridge.PenetrationRandomAngleMultiplier *= 0.5f; //change the accuracy when the bullet travels through an object
            customCartridge.Recoil *= 1.7f; //change the recoil
            customCartridge.ImpactForce *= 1f; //change how much the bullet pushes the target

            //set the cartridge to the FirearmBehaviour
            firearm.Cartridge = customCartridge;

            //set the new gun sounds. this is an array of AudioClips that is picked from at random when shot
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("shot.wav"),           
            };

            // set the collision box to the new sprite shape
            // this is the easiest way to fix your collision shape, but it also the slowest.
            Instance.FixColliders();
        }
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Revolver"), //item to derive from
        NameOverride = "TearDown Gun", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "A small grey weapon with a brown grip and a long barrel, the Gun is used to precisely break certain voxels at range. Any material not meant to be outright indestructible can be damaged by the Gun, albeit not very heavily, as the power of it's shots is quite limited. Despite this, it has a very long range and much faster firerate compared to the likes of the Shotgun and such.", //new item description
        CategoryOverride = ModAPI.FindCategory("Firearms"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("gunthumb.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //setting the sprite
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("gun.png");

            //getting the FirearmBehaviour for later manipulation
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //creating a custom cartridge for the gun
            Cartridge customCartridge = ModAPI.FindCartridge("9mm"); //load a copy of the 9mm cartridge
            customCartridge.name = "9mm"; //set a name
            customCartridge.Damage *= 30f; //change the damage however you like
            customCartridge.StartSpeed *= 357368f; //change the bullet velocity
            customCartridge.PenetrationRandomAngleMultiplier *= 0.5f; //change the accuracy when the bullet travels through an object
            customCartridge.Recoil *= 0.6f; //change the recoil
            customCartridge.ImpactForce *= 0f; //change how much the bullet pushes the target

            //set the cartridge to the FirearmBehaviour
            firearm.Cartridge = customCartridge;

            //set the new gun sounds. this is an array of AudioClips that is picked from at random when shot
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("gun.wav"),                               
            };

            // set the collision box to the new sprite shape
            // this is the easiest way to fix your collision shape, but it also the slowest.
            Instance.FixColliders();
        }
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Sniper Rifle"), //item to derive from
        NameOverride = "TearDown Hunting Rifle", //new item name with a suffix to assure it is globally unique
        DescriptionOverride = "The hunting rifle has one of the lowest fire rates in the game and a poor cooldown, but has high accuracy, precision and penetration to make up for this. The hunting rifle has a scope, long barrel, grip, and a stock. A good use for the hunting rifle is for sniping explosives from a considerable distance.", //new item description
        CategoryOverride = ModAPI.FindCategory("Firearms"), //new item category
        ThumbnailOverride = ModAPI.LoadSprite("huntingriflethumb.png"), //new item thumbnail (relative path)
        AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
        {
            //setting the sprite
            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("hunting rifle.png");

            //getting the FirearmBehaviour for later manipulation
            var firearm = Instance.GetComponent<FirearmBehaviour>();

            //creating a custom cartridge for the gun
            Cartridge customCartridge = ModAPI.FindCartridge("50 BMG"); //load a copy of the 9mm cartridge
            customCartridge.name = "50 BMG"; //set a name
            customCartridge.Damage *= 46f; //change the damage however you like
            customCartridge.StartSpeed *= 9368f; //change the bullet velocity
            customCartridge.PenetrationRandomAngleMultiplier *= 0.0f; //change the accuracy when the bullet travels through an object
            customCartridge.Recoil *= 0.3f; //change the recoil
            customCartridge.ImpactForce *= 2f; //change how much the bullet pushes the target

            //set the cartridge to the FirearmBehaviour
            firearm.Cartridge = customCartridge;

            //set the new gun sounds. this is an array of AudioClips that is picked from at random when shot
            firearm.ShotSounds = new AudioClip[]
            {
                ModAPI.LoadSound("gun2.wav"),
            };

            // set the collision box to the new sprite shape
            // this is the easiest way to fix your collision shape, but it also the slowest.
            Instance.FixColliders();
        }
    }
);

ModAPI.Register(
    new Modification()
    {
        OriginalItem = ModAPI.FindSpawnable("Human"),
        NameOverride = "TearDonw player",
        DescriptionOverride = "Even though you cant see yourself in TearDown, I just still wanted to bring a living thing in this mod.",
        CategoryOverride = ModAPI.FindCategory("Entities"),
        ThumbnailOverride = ModAPI.LoadSprite("ExampleSkinHumanThumb.png"),
        AfterSpawn = (Instance) =>
        {
            var skin = ModAPI.LoadTexture("ExampleSkinHuman.png");// textures
            var flesh = ModAPI.LoadTexture("ExampleFlesh.png");// textures
            var bone = ModAPI.LoadTexture("ExampleBone.png");// textures
            var person = Instance.GetComponent<PersonBehaviour>(); //dont change
            person.SetBodyTextures(skin, flesh, bone, 1); //dont change
            person.SetBruiseColor(86, 62, 130);//colors'n'stuff
            person.SetSecondBruiseColor(154, 0, 7);//colors'n'stuff
            person.SetThirdBruiseColor(207, 206, 120);//colors'n'stuff
            person.SetRottenColour(202, 199, 104);//colors'n'stuff
            person.SetBloodColour(108, 0, 4);//colors'n'stuff
        }
    }
);





        }
    }
}